Moderation in Askbot — Askbot 0.12.7 documentation

# Askbot Project Documentation

Home | Ask Questions | Consulting Services | Documentation | Contribute | Contact

# Moderation in Askbot

Regular users and forum Moderators can participate in the content moderation. Any user with sufficient reputation (this reputation threshold can be changed in the settings panel) can flag offensive posts.

When a post receives a certain number of flags (adjustable), the post is automatically hidden.

In addition users can delete posts, given a minimum reputation threshold (also adjustable) is met. Moderators can delete any post at any time.

Note

All the minimum reputation thresholds can be adjusted at the “settings” panel. Only site administrators have access to the settings editor.

Forum moderators can suspend and block users, by going to the “moderation” section in the user profile page. From the same page moderators can send an email to the user.

Suspended users can only edit own posts, but cannot make new posts. Blocked users can only sign in and send feedback to the side administrators.

Only site administrators can assign moderator status to any user.